# extglob [![NPM version](https://badge.fury.io/js/extglob.svg)](http://badge.fury.io/js/extglob)  [![Build Status](https://travis-ci.org/jonschlinkert/extglob.svg)](https://travis-ci.org/jonschlinkert/extglob) 

> Convert extended globs to regex-compatible strings. Add (almost) the expressive power of regular expressions to glob patterns.

## Install with [npm](npmjs.org)

```bash
npm i extglob --save
```

Used by [micromatch].

**Features**

- Convert an extglob string to a regex-compatible string. **Only converts extglobs**, to handle full globs use [micromatch].
- Pass `{regex: true}` to return a regex
- Handles nested patterns
- More complete (and correct) support than [minimatch](https://github.com/isaacs/minimatch)

## Usage

```js
var extglob = require('extglob');

extglob('?(z)');
//=> '(?:z)?'
extglob('*(z)');
//=> '(?:z)*'
extglob('+(z)');
//=> '(?:z)+'
extglob('@(z)');
//=> '(?:z)'
extglob('!(z)');
//=> '(?!^(?:(?!z)[^/]*?)).*$'
```

**Optionally return regex**

```js
extglob('!(z)', {regex: true});
//=> /(?!^(?:(?!z)[^/]*?)).*$/
```

## Extglob patterns

To learn more about how extglobs work, see the docs for [Bash pattern matching][bash]:

- `?(pattern)`: Match zero or one occurrence of the given pattern.
- `*(pattern)`: Match zero or more occurrences of the given pattern.
- `+(pattern)`: Match one or more occurrences of the given pattern.
- `@(pattern)`: Match one of the given pattern.
- `!(pattern)`: Match anything except one of the given pattern.

## Run tests
Install dev dependencies:

```bash
npm i -d && npm test
```

## Contributing
Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/extglob/issues)

## Author

**Jon Schlinkert**

+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert) 

## License
Copyright (c) 2015 Jon Schlinkert  
Released under the MIT license

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on April 18, 2015._

[bash]: https://www.gnu.org/software/bash/manual/html_node/Pattern-Matching.html
[micromatch]: https://github.com/jonschlinkert/micromatch
